#ifdef __WXMAC_CLASSIC__
#include "wx/mac/classic/pnghand.h"
#else
#include "wx/mac/carbon/pnghand.h"
#endif
